==> vite-plugin-proxy-0.4.2.tgz: package/test/frontends/manifests.test.js <==
import { describe, it, expect, afterEach } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import vitePluginOxManifests from '@open-xchange/vite-plugin-ox-manifests'
import { closeAllServers, createTestServer, createViteServer, getPort, http2Request, updateRequestManager } from '../util'
import fastifyCompress from 'fastify-compress'

const PORT = getPort()
const SERVER_PORT = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('manifests', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('serves merged manifest.json', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      }), vitePluginOxManifests({
        // no config
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/manifests', (req, res) => {
      res.send([{ namespace: 'other' }])
    })
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://localhost:${PORT}/manifests`)
    expect(data).toEqual([{
      namespace: 'other'
    }, {
      namespace: 'index',
      path: 'index'
    }])
  })

  it('overrides manifest.json with local manifests', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        // this has to be thought of as a remote UI with the same files
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      }), vitePluginOxManifests({
        // no config
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/manifests', (req, res) => {
      res.send([{ namespace: 'index', path: 'index', requires: 'chat' }])
    })
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://localhost:${PORT}/manifests`)
    expect(data).toEqual([{
      namespace: 'index',
      path: 'index'
    }])
  })

  describe('compression', function () {
    it('serves gzipped manifests', async function () {
      await createViteServer({
        root: __dirname,
        logLevel: 'silent',
        plugins: [vitePluginProxy({
          frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
        }), vitePluginOxManifests({
          // no config
        })]
      }, PORT)

      const server = createTestServer()
      server.register(fastifyCompress, { threshold: 1, forceRequestEncoding: 'gzip', encodings: ['gzip'] })
      server.get('/manifests', (req, res) => {
        res.send([{ namespace: 'other' }])
      })
      await server.listen(SERVER_PORT)

      const { data } = await http2Request(`http://localhost:${PORT}/manifests`)

      expect(data).toEqual([{
        namespace: 'other'
      }, {
        namespace: 'index',
        path: 'index'
      }])
    })

    it('serves inflated manifests', async function () {
      await createViteServer({
        root: __dirname,
        logLevel: 'silent',
        plugins: [vitePluginProxy({
          frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
        }), vitePluginOxManifests({
          // no config
        })]
      }, PORT)

      const server = createTestServer()
      server.register(fastifyCompress, { threshold: 1, forceRequestEncoding: 'deflate', encodings: ['deflate'] })
      server.get('/manifests', (req, res) => {
        res.send([{ namespace: 'other' }])
      })
      await server.listen(SERVER_PORT)

      const { data } = await http2Request(`http://localhost:${PORT}/manifests`)

      expect(data).toEqual([{
        namespace: 'other'
      }, {
        namespace: 'index',
        path: 'index'
      }])
    })
  })
})

==> vite-plugin-proxy-0.4.4.tgz: package/test/frontends/manifests.test.js <==
import { describe, it, expect, afterEach } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import vitePluginOxManifests from '@open-xchange/vite-plugin-ox-manifests'
import { closeAllServers, createTestServer, createViteServer, getPort, http2Request, updateRequestManager } from '../util'
import fastifyCompress from 'fastify-compress'

const PORT = getPort()
const SERVER_PORT = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('manifests', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('serves merged manifest.json', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      }), vitePluginOxManifests({
        // no config
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/manifests', (req, res) => {
      res.send([{ namespace: 'other' }])
    })
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://127.0.0.1:${PORT}/manifests`)
    expect(data).toEqual([{
      namespace: 'other'
    }, {
      namespace: 'index',
      path: 'index'
    }])
  })

  it('overrides manifest.json with local manifests', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        // this has to be thought of as a remote UI with the same files
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      }), vitePluginOxManifests({
        // no config
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/manifests', (req, res) => {
      res.send([{ namespace: 'index', path: 'index', requires: 'chat' }])
    })
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://127.0.0.1:${PORT}/manifests`)
    expect(data).toEqual([{
      namespace: 'index',
      path: 'index'
    }])
  })

  describe('compression', function () {
    it('serves gzipped manifests', async function () {
      await createViteServer({
        root: __dirname,
        logLevel: 'silent',
        plugins: [vitePluginProxy({
          frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
        }), vitePluginOxManifests({
          // no config
        })]
      }, PORT)

      const server = createTestServer()
      server.register(fastifyCompress, { threshold: 1, forceRequestEncoding: 'gzip', encodings: ['gzip'] })
      server.get('/manifests', (req, res) => {
        res.send([{ namespace: 'other' }])
      })
      await server.listen(SERVER_PORT)

      const { data } = await http2Request(`http://127.0.0.1:${PORT}/manifests`)

      expect(data).toEqual([{
        namespace: 'other'
      }, {
        namespace: 'index',
        path: 'index'
      }])
    })

    it('serves inflated manifests', async function () {
      await createViteServer({
        root: __dirname,
        logLevel: 'silent',
        plugins: [vitePluginProxy({
          frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
        }), vitePluginOxManifests({
          // no config
        })]
      }, PORT)

      const server = createTestServer()
      server.register(fastifyCompress, { threshold: 1, forceRequestEncoding: 'deflate', encodings: ['deflate'] })
      server.get('/manifests', (req, res) => {
        res.send([{ namespace: 'other' }])
      })
      await server.listen(SERVER_PORT)

      const { data } = await http2Request(`http://127.0.0.1:${PORT}/manifests`)

      expect(data).toEqual([{
        namespace: 'other'
      }, {
        namespace: 'index',
        path: 'index'
      }])
    })
  })

  it('serves merged manifest.json from a different base', async function () {
    await createViteServer({
      root: __dirname,
      base: '/appsuite/',
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      }), vitePluginOxManifests({
        // no config
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/appsuite/manifests', (req, res) => {
      res.send([{ namespace: 'other' }])
    })
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://127.0.0.1:${PORT}/appsuite/manifests`)
    expect(data).toEqual([{
      namespace: 'other'
    }, {
      namespace: 'index',
      path: 'index'
    }])
  })
})
